%% 6.581 Problem set 2
%% Question 2
%% reflect.m, called by estatic.m

function [eval] = reflect(src, sep)
% Reflection of a charge cluster centered at x = 0.5 
% about x = a plane where a = (1-sep)/2
%
% src  : coordinates of a charge in source cluster
% eval : coordinates of a reflected charge (src) in evaluation cluster
% sep  : separation between centers of source and evaluation clusters

eval = src;
eval(1) = 1-sep-src(1);